@@ -36,7 +36,7 @@ class QAStage(Stage):
     __REFACTOR_QUESTION__ = "refactor_questions"
 
     def __init__(self, data):
-        super(QAStage, self).__init__()
+        super(QAStage, self).__init__(**data)
         self.raw_data = data
         self.stage_type = data.get("stage_type")
         self.corpus = {}
@@ -146,7 +146,7 @@ class QAStage(Stage):
 class REStage(Stage):
 
     def __init__(self, data):
-        super(REStage, self).__init__()
+        super(REStage, self).__init__(**data)
         self.raw_data = data
         self.stage_type = data.get("stage_type")
 
@@ -203,7 +203,7 @@ class REStage(Stage):
 class LibSwitchStage(Stage):
 
     def __init__(self, data):
-        super(LibSwitchStage, self).__init__()
+        super(LibSwitchStage, self).__init__(**data)
         self.raw_data = data
         self.stage_type = StageType.SWITCH
         self.stages_filter = data.get("stages_filter")
