@@ -29,6 +29,7 @@ class Agent:
     @classmethod
     def get_sys_reply(cls, data):
         reply: list = data.get(__SYS_REPLY__, [])
+        reply = [line for line in reply if line != ""]
         return reply
 
     @staticmethod
@@ -84,6 +85,8 @@ class MultiAgent(Agent):
 
     def run_one_stages(self, stages, kwargs):
         for idx, stage in enumerate(stages):
+
+            # clear data for loop map
             if stage.stage_id in self.__STAGES_IDS__:
                 for rm_idx in self.__STAGES_IDS__[self.__STAGES_IDS__.index(stage.stage_id):]:
                     if rm_idx in kwargs[__PASS_TOKEN__]:
@@ -93,8 +96,13 @@ class MultiAgent(Agent):
                             if var_name in kwargs[__KEEP_VAR__][__KEEP_DEFAULT_VAR__]:
                                 del kwargs[__KEEP_VAR__][__KEEP_DEFAULT_VAR__][var_name]
                         del kwargs[__KEEP_VAR__][rm_idx]
-            self.__STAGES_IDS__.append(stage.stage_id)
+                
+                # reset self.__STAGES_IDS__ because delete loop stage from user data
+                self.__STAGES_IDS__ = self.__STAGES_IDS__[:self.__STAGES_IDS__.index(stage.stage_id)]
 
+
+            #
+            self.__STAGES_IDS__.append(stage.stage_id)
             ##
 
             if self.is_switch_stage(stage) is True:
