@@ -1,7 +1,7 @@
 import json
 import uuid
 import re
-
+import random
 __USER_TEXT__ = "USER_TEXT"
 __PASS_TOKEN__ = "PASS_TOKEN"
 __SYS_REPLY__ = "SYS_REPLY"
@@ -27,7 +27,8 @@ class StageType:
 class Stage:
     def __init__(self, **kwargs):
         self.stage_type = StageType.BASE
-        self.stage_id = f"{self.stage_type}:{str(uuid.uuid4())[:15]}"
+        self.stage_uuid_name = kwargs.get("__STAGE_NAME__", str(uuid.uuid4())[:15])
+        self.stage_id = f"{self.stage_type}:{self.stage_uuid_name}"
         self.data = kwargs
         self.sys_reply_q1 = "init sys reply"  # init
         self.sys_reply_q2 = "refuse sys reply"  # refuse
@@ -191,13 +192,17 @@ class Stage:
         if self.is_first_access(kwargs, self.stage_id) is True:
             kwargs = self.set_none_token_pass(data=kwargs, stage_id=self.stage_id)
             kwargs = self.set_sys_stage_status(kwargs, StageStatus.FIRST)
-            sys_reply = self.replace_var_ticket_to_string(kwargs, self.sys_reply_q1)
+            sys_reply = self.__choice_a_reply__(self.sys_reply_q1)
+            #
+            sys_reply = self.replace_var_ticket_to_string(kwargs, sys_reply)
             return self.set_sys_reply(kwargs, sys_reply)
 
         is_fit_token, kwargs = self.is_fit_needs_n_gen_entity(kwargs)
         if is_fit_token is False:  # q1
             kwargs = self.set_sys_stage_status(kwargs, StageStatus.REFUSE)
-            sys_reply = self.replace_var_ticket_to_string(kwargs, self.sys_reply_q2)
+            sys_reply = self.__choice_a_reply__(self.sys_reply_q2)
+
+            sys_reply = self.replace_var_ticket_to_string(kwargs, sys_reply)
             return self.set_sys_reply(kwargs, sys_reply)
 
         elif is_fit_token is True and kwargs is not None:  # q2
@@ -207,13 +212,19 @@ class Stage:
             kwargs = self.set_sys_stage_status(kwargs, StageStatus.COMPLETE)
 
             # insert ENTITY
-            sys_reply = self.replace_var_ticket_to_string(kwargs, self.sys_reply_complete)
+            sys_reply = self.replace_var_ticket_to_string(kwargs, self.__choice_a_reply__(self.sys_reply_complete))
             return self.set_sys_reply(kwargs, sys_reply)
 
         elif is_fit_token is True and kwargs is None:  # reset route
-            sys_reply = self.replace_var_ticket_to_string(kwargs, self.sys_reply_complete)
+            sys_reply = self.replace_var_ticket_to_string(kwargs, self.__choice_a_reply__(self.sys_reply_complete))
             return self.set_sys_reply({}, sys_reply)
 
+    def __choice_a_reply__(self, sys_reply):
+        if isinstance(sys_reply, list):
+            sys_reply = random.choice(sys_reply)
+            return sys_reply
+        return sys_reply
+
 
 a = Stage()
 res = a.run()
